@@ -1,29 +1,24 @@
 use crate::log::{println_label, OutputLabel};
 use git2::{Branch, BranchType, Repository, Status};
-use std::path::Path;
 
 pub fn is_repo_dirty(repo: &Repository) -> bool {
-	let mut dirty = false;
-
 	if let Ok(statuses) = repo.statuses(None) {
 		for status in statuses.iter() {
 			match status.status() {
 				Status::IGNORED => continue,
 				_ => {
-					dirty = true;
-					break;
+					return true;
 				}
 			}
 		}
 	}
 
-	dirty
+	false
 }
 
 pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 	// Iterate over all local branches
 	// For each, check is a branch is ahead of its remote counterpart
-	// If so, return true
 
 	// Get all local branches
 	let local_branches = repo
@@ -38,13 +33,19 @@ pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 	for branch in local_branches {
 		if let Ok(remote_branch) = branch.upstream() {
 			let (last_local_commit, last_remote_commit) = (
-				branch.get().peel_to_commit().unwrap(),
-				remote_branch.get().peel_to_commit().unwrap(),
+				branch
+					.get()
+					.peel_to_commit()
+					.expect("could not get last commit on local branch"),
+				remote_branch
+					.get()
+					.peel_to_commit()
+					.expect("could not get last commit on remote branch"),
 			);
 
 			if repo
 				.graph_descendant_of(last_local_commit.id(), last_remote_commit.id())
-				.unwrap()
+				.expect("could not get graph difference between commits")
 			{
 				ahead_branches.push(branch)
 			}
@@ -62,10 +63,3 @@ pub fn find_ahead_branches_in_repo(repo: &Repository) -> Vec<Branch> {
 
 	ahead_branches
 }
-
-/// Get the project name from various sources (cargo.toml, package.json, etc.) fallback to folder name
-pub fn _get_project_name(_path: &Path) -> Option<String> {
-	// TODO: implement
-
-	None
-}
